@@ -111,6 +111,7 @@ void Settings::ReadFromAddon(const std::string& userPath, const std::string& cli
   m_logoPath = kodi::GetSettingString("logoPath");
   m_logoBaseUrl = kodi::GetSettingString("logoBaseUrl");
   m_epgLogosMode = kodi::GetSettingEnum<EpgLogosMode>("logoFromEpg", EpgLogosMode::IGNORE_XMLTV);
+  m_useLocalLogosOnly = kodi::GetSettingBoolean("useLogosLocalPathOnly", false);
 
   // Timeshift
   m_timeshiftEnabled = kodi::GetSettingBoolean("timeshiftEnabled", false);
@@ -124,6 +125,8 @@ void Settings::ReadFromAddon(const std::string& userPath, const std::string& cli
   m_catchupQueryFormat = kodi::GetSettingString("catchupQueryFormat");
   m_catchupDays = kodi::GetSettingInt("catchupDays", 5);
   m_allChannelsCatchupMode = kodi::GetSettingEnum<CatchupMode>("allChannelsCatchupMode", CatchupMode::DISABLED);
+  m_catchupOverrideMode = kodi::GetSettingEnum<CatchupOverrideMode>("catchupOverrideMode", CatchupOverrideMode::WITHOUT_TAGS);
+  m_catchupCorrectionHours = kodi::GetSettingFloat("catchupCorrection", 0.0f);
   m_catchupPlayEpgAsLive = kodi::GetSettingBoolean("catchupPlayEpgAsLive", false);
   m_catchupWatchEpgBeginBufferMins = kodi::GetSettingInt("catchupWatchEpgBeginBufferMins", 5);
   m_catchupWatchEpgEndBufferMins = kodi::GetSettingInt("catchupWatchEpgEndBufferMins", 15);
@@ -243,6 +246,8 @@ ADDON_STATUS Settings::SetValue(const std::string& settingName, const kodi::CSet
     return SetStringSetting<ADDON_STATUS>(settingName, settingValue, m_logoBaseUrl, ADDON_STATUS_OK, ADDON_STATUS_OK);
   else if (settingName == "logoFromEpg")
     return SetEnumSetting<EpgLogosMode, ADDON_STATUS>(settingName, settingValue, m_epgLogosMode, ADDON_STATUS_OK, ADDON_STATUS_OK);
+  else if (settingName == "useLogosLocalPathOnly")
+    return SetSetting<bool, ADDON_STATUS>(settingName, settingValue, m_useLocalLogosOnly, ADDON_STATUS_OK, ADDON_STATUS_OK);
   // Timeshift
   else if (settingName == "timeshiftEnabled")
     return SetSetting<bool, ADDON_STATUS>(settingName, settingValue, m_timeshiftEnabled, ADDON_STATUS_OK, ADDON_STATUS_OK);
@@ -263,6 +268,10 @@ ADDON_STATUS Settings::SetValue(const std::string& settingName, const kodi::CSet
     return SetSetting<int, ADDON_STATUS>(settingName, settingValue, m_catchupDays, ADDON_STATUS_OK, ADDON_STATUS_OK);
   else if (settingName == "allChannelsCatchupMode")
     return SetEnumSetting<CatchupMode, ADDON_STATUS>(settingName, settingValue, m_allChannelsCatchupMode, ADDON_STATUS_OK, ADDON_STATUS_OK);
+  else if (settingName == "catchupOverrideMode")
+    return SetEnumSetting<CatchupOverrideMode, ADDON_STATUS>(settingName, settingValue, m_catchupOverrideMode, ADDON_STATUS_OK, ADDON_STATUS_OK);
+  else if (settingName == "catchupCorrection")
+    return SetSetting<float, ADDON_STATUS>(settingName, settingValue, m_catchupCorrectionHours, ADDON_STATUS_OK, ADDON_STATUS_OK);
   else if (settingName == "catchupPlayEpgAsLive")
     return SetSetting<bool, ADDON_STATUS>(settingName, settingValue, m_catchupPlayEpgAsLive, ADDON_STATUS_OK, ADDON_STATUS_OK);
   else if (settingName == "catchupWatchEpgBeginBufferMins")
